#!/usr/bin/env python
# coding: utf-8


"""

======PROJECT======

MathEnergy

======DESCRIPTION======

Setting up logger for the demonstrator.

​======Overview functions=====

01: def setup_logger(log_dir = None, loglevel = logging.DEBUG)

======AUTHOR, CONTACT & DATE======

Paul Verwiebe, Department of Energy and Resource Management, Technical University of Berlin

verwiebe@tu-berlin.de

June 2021

"""



# ---IMPORT STATEMENTS---
import os
import logging
import logging.config



# ---FUNCTIONS---
# 01
def setup_logger(log_dir = None, loglevel = logging.DEBUG):
    """Instantiate logger.

    Parameters
    ----------
    log_dir : str
        Directory to save log. The default is: <package_dir>/../../logs/
        
    loglevel
        Specifies the lowest-severity log message a logger will handle.

    Returns
    -------
    Instance of logger.
    
    Notes
    -----
    - logger = logging.getLogger('mathenergy')
    - msg = 'error message'
    - logger.error(msg)
    - logger.info('info message')
    """

    if log_dir is None:
        log_dir = os.path.join(os.path.expanduser('~'), '.mathenergy/logger')

    # Log dir does not exist
    if not os.path.isdir(log_dir):
        os.makedirs(log_dir)

    logger = logging.getLogger('mathenergy') # Use filename as name in log
    logger.setLevel(loglevel)

    # Create a file handler
    handler = logging.FileHandler(os.path.join(log_dir, 'mathenergy.log'))
    handler.setLevel(logging.DEBUG)
    formatter = logging.Formatter('%(asctime)s-%(levelname)s-%(funcName)s: %(message)s')
    handler.setFormatter(formatter)

    # Create a stream handler (print to prompt)
    stream = logging.StreamHandler()
    stream.setLevel(logging.INFO)
    stream_formatter = logging.Formatter('%(asctime)s-%(levelname)s: %(message)s', '%H:%M:%S')
    stream.setFormatter(stream_formatter)

    # Add the handlers to the logger
    logger.addHandler(handler)
    logger.addHandler(stream)

    logger.propagate = False

    logger.debug('*********************************************************')
    logger.info('Path for logging: %s' % log_dir)

    return logger